@@ -28,21 +28,21 @@ def check_node():
         ).replace("v", "")
         major_version = int(extract_number(node_version))
 
-        MIN_VER = 16
+        MIN_VER = 14
         if major_version < MIN_VER:
             print(
-                f"Your Node.js version is {major_version}, which is less than {MIN_VER}. To use the stealth and auth proxy features of Botasaurus, you need Node.js {MIN_VER}, Kindly install it by visiting https://nodejs.org/"
+                f"Your Node.js version is {major_version}, which is less than {MIN_VER}. To use proxy with Botasaurus, you need Node.js {MIN_VER}+, Kindly install it by visiting https://nodejs.org/."
             )
             sys.exit(1)
     except Exception as e:
         print(
-            "Botasaurus requires Node.js for its stealth and proxy features. You do not have node installed on your system, Kindly install it by visiting https://nodejs.org/. After installation, please restart your PC."
+            "To use proxy with Botasaurus, you need to have Node.js installed on your system. You do not have Node.js installed on your system, Kindly install it by visiting https://nodejs.org/. After installation, please restart your PC."
         )
         sys.exit(1)
 
 def packageinstall():
     base_path = os.path.join(os.path.dirname(__file__), "js", "node_modules")
-    has_paths = os.path.exists(os.path.join(base_path, "proxy-chain")) and os.path.exists(os.path.join(base_path, "chrome-launcher")) and os.path.exists(os.path.join(base_path, "got-scraping-export")) and os.path.exists(os.path.join(base_path, "botasaurus-controls"))
+    has_paths = os.path.exists(os.path.join(base_path, "proxy-chain"))  and os.path.exists(os.path.join(base_path, "botasaurus-controls"))
     
     if not has_paths: 
         check_node()
@@ -55,7 +55,7 @@ def packageinstall():
                 f.write(PACKAGEJSON)
         
         
-        os.system(f"npm install proxy-chain chrome-launcher got-scraping-export botasaurus-controls")
+        os.system(f"npm install proxy-chain botasaurus-controls")
 
         os.chdir(original_directory)
 
@@ -64,15 +64,21 @@ packageinstall()
 from . import config, proxy, events
 import threading, inspect, time, atexit
 
-
 def init():
+    global console, globalThis, RegExp, start, stop, abort
     if config.event_loop:
         return  # Do not start event loop again
     config.event_loop = events.EventLoop()
+    start = config.event_loop.startThread
+    stop = config.event_loop.stopThread
+    abort = config.event_loop.abortThread
     config.event_thread = threading.Thread(target=config.event_loop.loop, args=(), daemon=True)
     config.event_thread.start()
     config.executor = proxy.Executor(config.event_loop)
     config.global_jsi = proxy.Proxy(config.executor, 0)
+    console = config.global_jsi.console  # TODO: Remove this in 1.0
+    globalThis = config.global_jsi.globalThis
+    RegExp = config.global_jsi.RegExp
     atexit.register(config.event_loop.on_exit)
 
     if config.global_jsi.needsNodePatches():
@@ -82,6 +88,11 @@ def init():
 init()
 
 
+def terminate():
+    if config.event_loop:
+        config.event_loop.stop()
+
+
 def require(name, version=None):
     calling_dir = None
     if name.startswith("."):
@@ -99,11 +110,6 @@ def require(name, version=None):
     return config.global_jsi.require(name, version, calling_dir, timeout=900)
 
 
-console = config.global_jsi.console  # TODO: Remove this in 1.0
-globalThis = config.global_jsi.globalThis
-RegExp = config.global_jsi.RegExp
-
-
 def eval_js(js):
     frame = inspect.currentframe()
     rv = None
@@ -128,10 +134,6 @@ def AsyncTask(start=False):
     return decor
 
 
-start = config.event_loop.startThread
-stop = config.event_loop.stopThread
-abort = config.event_loop.abortThread
-
 # You must use this Once decorator for an EventEmitter in Node.js, otherwise
 # you will not be able to off an emitter.
 def On(emitter, event):
